@@ -14,7 +14,6 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_batch.paginator import (
@@ -57,6 +56,14 @@ else:
 __all__ = ("BatchClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     ClientError: Type[BotocoreClientError]
     ClientException: Type[BotocoreClientError]
